==> ViennaCL-1.6.0.tar.gz: ViennaCL-1.6.0/doc/html/search/classes_14.js <==
var searchData=
[
  ['value_5ftype',['value_type',['../structviennacl_1_1result__of_1_1value__type.html',1,'viennacl::result_of']]],
  ['vandermonde_5fmatrix',['vandermonde_matrix',['../classviennacl_1_1vandermonde__matrix.html',1,'viennacl']]],
  ['vector',['vector',['../classviennacl_1_1vector.html',1,'viennacl']]],
  ['vector',['vector',['../classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector.html',1,'viennacl::linalg::opencl::kernels']]],
  ['vector_3c_20numerict_20_3e',['vector&lt; NumericT &gt;',['../classviennacl_1_1vector.html',1,'viennacl']]],
  ['vector_3c_20numerict_2c_20alignmentv_20_3e',['vector&lt; NumericT, AlignmentV &gt;',['../classviennacl_1_1vector.html',1,'viennacl']]],
  ['vector_3c_20numerictype_20_3e',['vector&lt; NumericType &gt;',['../classviennacl_1_1vector.html',1,'viennacl']]],
  ['vector_3c_20scalartype_20_3e',['vector&lt; ScalarType &gt;',['../classviennacl_1_1vector.html',1,'viennacl']]],
  ['vector_3c_20unsigned_20int_20_3e',['vector&lt; unsigned int &gt;',['../classviennacl_1_1vector.html',1,'viennacl']]],
  ['vector_5farray_5fwrapper',['vector_array_wrapper',['../classviennacl_1_1linalg_1_1host__based_1_1detail_1_1vector__array__wrapper.html',1,'viennacl::linalg::host_based::detail']]],
  ['vector_5faxpy_5fparameters',['vector_axpy_parameters',['../classviennacl_1_1device__specific_1_1vector__axpy__parameters.html',1,'viennacl::device_specific']]],
  ['vector_5faxpy_5ftemplate',['vector_axpy_template',['../classviennacl_1_1device__specific_1_1vector__axpy__template.html',1,'viennacl::device_specific']]],
  ['vector_5fbase',['vector_base',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20char_20_3e',['vector_base&lt; char &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20double_20_3e',['vector_base&lt; double &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20float_20_3e',['vector_base&lt; float &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20int_20_3e',['vector_base&lt; int &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20long_20_3e',['vector_base&lt; long &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20numerict_20_3e',['vector_base&lt; NumericT &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20short_20_3e',['vector_base&lt; short &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20unsigned_20char_20_3e',['vector_base&lt; unsigned char &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20unsigned_20int_20_3e',['vector_base&lt; unsigned int &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20unsigned_20long_20_3e',['vector_base&lt; unsigned long &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20unsigned_20short_20_3e',['vector_base&lt; unsigned short &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20vectortype_3a_3acpu_5fvalue_5ftype_20_3e',['vector_base&lt; VectorType::cpu_value_type &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5felement',['vector_element',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__element.html',1,'viennacl::linalg::opencl::kernels']]],
  ['vector_5fexpression',['vector_expression',['../classviennacl_1_1vector__expression.html',1,'viennacl']]],
  ['vector_5fiterator',['vector_iterator',['../classviennacl_1_1vector__iterator.html',1,'viennacl']]],
  ['vector_5fmulti_5finner_5fprod',['vector_multi_inner_prod',['../classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__multi__inner__prod.html',1,'viennacl::linalg::opencl::kernels']]],
  ['vector_5frange',['vector_range',['../classviennacl_1_1vector__range.html',1,'viennacl']]],
  ['vector_5frange_3c_20vector_5frange_3c_20vectortype_20_3e_20_3e',['vector_range&lt; vector_range&lt; VectorType &gt; &gt;',['../classviennacl_1_1vector__range_3_01vector__range_3_01_vector_type_01_4_01_4.html',1,'viennacl']]],
  ['vector_5fslice',['vector_slice',['../classviennacl_1_1vector__slice.html',1,'viennacl']]],
  ['vector_5fslice_3c_20vector_5fslice_3c_20vectortype_20_3e_20_3e',['vector_slice&lt; vector_slice&lt; VectorType &gt; &gt;',['../classviennacl_1_1vector__slice_3_01vector__slice_3_01_vector_type_01_4_01_4.html',1,'viennacl']]],
  ['vector_5ftuple',['vector_tuple',['../classviennacl_1_1vector__tuple.html',1,'viennacl']]],
  ['viennaclbackend_5fimpl',['ViennaCLBackend_impl',['../struct_vienna_c_l_backend__impl.html',1,'']]],
  ['viennaclcudabackend_5fimpl',['ViennaCLCUDABackend_impl',['../struct_vienna_c_l_c_u_d_a_backend__impl.html',1,'']]],
  ['viennaclhostbackend_5fimpl',['ViennaCLHostBackend_impl',['../struct_vienna_c_l_host_backend__impl.html',1,'']]],
  ['viennaclhostscalar_5fimpl',['ViennaCLHostScalar_impl',['../struct_vienna_c_l_host_scalar__impl.html',1,'']]],
  ['viennaclmatrix_5fimpl',['ViennaCLMatrix_impl',['../struct_vienna_c_l_matrix__impl.html',1,'']]],
  ['viennaclopenclbackend_5fimpl',['ViennaCLOpenCLBackend_impl',['../struct_vienna_c_l_open_c_l_backend__impl.html',1,'']]],
  ['viennaclscalar_5fimpl',['ViennaCLScalar_impl',['../struct_vienna_c_l_scalar__impl.html',1,'']]],
  ['viennaclvector_5fimpl',['ViennaCLVector_impl',['../struct_vienna_c_l_vector__impl.html',1,'']]]
];

==> ViennaCL-1.6.1.tar.gz: ViennaCL-1.6.1/doc/html/search/classes_14.js <==
var searchData=
[
  ['value_5ftype',['value_type',['../structviennacl_1_1result__of_1_1value__type.html',1,'viennacl::result_of']]],
  ['vandermonde_5fmatrix',['vandermonde_matrix',['../classviennacl_1_1vandermonde__matrix.html',1,'viennacl']]],
  ['vector',['vector',['../classviennacl_1_1vector.html',1,'viennacl']]],
  ['vector',['vector',['../classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector.html',1,'viennacl::linalg::opencl::kernels']]],
  ['vector_3c_20numerict_20_3e',['vector&lt; NumericT &gt;',['../classviennacl_1_1vector.html',1,'viennacl']]],
  ['vector_3c_20numerictype_20_3e',['vector&lt; NumericType &gt;',['../classviennacl_1_1vector.html',1,'viennacl']]],
  ['vector_3c_20scalartype_20_3e',['vector&lt; ScalarType &gt;',['../classviennacl_1_1vector.html',1,'viennacl']]],
  ['vector_3c_20unsigned_20int_20_3e',['vector&lt; unsigned int &gt;',['../classviennacl_1_1vector.html',1,'viennacl']]],
  ['vector_5farray_5fwrapper',['vector_array_wrapper',['../classviennacl_1_1linalg_1_1host__based_1_1detail_1_1vector__array__wrapper.html',1,'viennacl::linalg::host_based::detail']]],
  ['vector_5faxpy_5fparameters',['vector_axpy_parameters',['../classviennacl_1_1device__specific_1_1vector__axpy__parameters.html',1,'viennacl::device_specific']]],
  ['vector_5faxpy_5ftemplate',['vector_axpy_template',['../classviennacl_1_1device__specific_1_1vector__axpy__template.html',1,'viennacl::device_specific']]],
  ['vector_5fbase',['vector_base',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20char_20_3e',['vector_base&lt; char &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20double_20_3e',['vector_base&lt; double &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20float_20_3e',['vector_base&lt; float &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20int_20_3e',['vector_base&lt; int &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20long_20_3e',['vector_base&lt; long &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20numerict_20_3e',['vector_base&lt; NumericT &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20numerictype_20_3e',['vector_base&lt; NumericType &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20scalartype_20_3e',['vector_base&lt; ScalarType &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20short_20_3e',['vector_base&lt; short &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20unsigned_20char_20_3e',['vector_base&lt; unsigned char &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20unsigned_20int_20_3e',['vector_base&lt; unsigned int &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20unsigned_20long_20_3e',['vector_base&lt; unsigned long &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20unsigned_20short_20_3e',['vector_base&lt; unsigned short &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5fbase_3c_20vectortype_3a_3acpu_5fvalue_5ftype_20_3e',['vector_base&lt; VectorType::cpu_value_type &gt;',['../classviennacl_1_1vector__base.html',1,'viennacl']]],
  ['vector_5felement',['vector_element',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__element.html',1,'viennacl::linalg::opencl::kernels']]],
  ['vector_5fexpression',['vector_expression',['../classviennacl_1_1vector__expression.html',1,'viennacl']]],
  ['vector_5fiterator',['vector_iterator',['../classviennacl_1_1vector__iterator.html',1,'viennacl']]],
  ['vector_5fmulti_5finner_5fprod',['vector_multi_inner_prod',['../classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__multi__inner__prod.html',1,'viennacl::linalg::opencl::kernels']]],
  ['vector_5fproxy',['vector_proxy',['../classvector__proxy.html',1,'']]],
  ['vector_5frange',['vector_range',['../classviennacl_1_1vector__range.html',1,'viennacl']]],
  ['vector_5frange_3c_20vector_5frange_3c_20vectortype_20_3e_20_3e',['vector_range&lt; vector_range&lt; VectorType &gt; &gt;',['../classviennacl_1_1vector__range_3_01vector__range_3_01_vector_type_01_4_01_4.html',1,'viennacl']]],
  ['vector_5fslice',['vector_slice',['../classviennacl_1_1vector__slice.html',1,'viennacl']]],
  ['vector_5fslice_3c_20vector_5fslice_3c_20vectortype_20_3e_20_3e',['vector_slice&lt; vector_slice&lt; VectorType &gt; &gt;',['../classviennacl_1_1vector__slice_3_01vector__slice_3_01_vector_type_01_4_01_4.html',1,'viennacl']]],
  ['vector_5ftuple',['vector_tuple',['../classviennacl_1_1vector__tuple.html',1,'viennacl']]],
  ['viennaclbackend_5fimpl',['ViennaCLBackend_impl',['../struct_vienna_c_l_backend__impl.html',1,'']]],
  ['viennaclcudabackend_5fimpl',['ViennaCLCUDABackend_impl',['../struct_vienna_c_l_c_u_d_a_backend__impl.html',1,'']]],
  ['viennaclhostbackend_5fimpl',['ViennaCLHostBackend_impl',['../struct_vienna_c_l_host_backend__impl.html',1,'']]],
  ['viennaclhostscalar_5fimpl',['ViennaCLHostScalar_impl',['../struct_vienna_c_l_host_scalar__impl.html',1,'']]],
  ['viennaclmatrix_5fimpl',['ViennaCLMatrix_impl',['../struct_vienna_c_l_matrix__impl.html',1,'']]],
  ['viennaclopenclbackend_5fimpl',['ViennaCLOpenCLBackend_impl',['../struct_vienna_c_l_open_c_l_backend__impl.html',1,'']]],
  ['viennaclscalar_5fimpl',['ViennaCLScalar_impl',['../struct_vienna_c_l_scalar__impl.html',1,'']]],
  ['viennaclvector_5fimpl',['ViennaCLVector_impl',['../struct_vienna_c_l_vector__impl.html',1,'']]]
];
